@@ -18,12 +18,13 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "log.h"
+
 #include <KAboutData>
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KHelpMenu>
 #include <kio/deletejob.h>
-#include <KLocalizedString>
 #include <KRecentFilesAction>
 #include <KSharedConfig>
 #include <KShortcutsDialog>
@@ -50,6 +51,23 @@
 #include "mainwindow.h"
 #include "playlist/playlisttab.h"
 
+// log categories. Should match log.h
+
+Q_LOGGING_CATEGORY(logCam, "kaffeine.cam")
+Q_LOGGING_CATEGORY(logDev, "kaffeine.dev")
+Q_LOGGING_CATEGORY(logDvb, "kaffeine.dvb")
+Q_LOGGING_CATEGORY(logDvbSi, "kaffeine.dvbsi")
+Q_LOGGING_CATEGORY(logEpg, "kaffeine.epg")
+
+Q_LOGGING_CATEGORY(logConfig, "kaffeine.config")
+Q_LOGGING_CATEGORY(logMediaWidget, "kaffeine.mediawidget")
+Q_LOGGING_CATEGORY(logPlaylist, "kaffeine.playlist")
+Q_LOGGING_CATEGORY(logSql, "kaffeine.sql")
+
+#define FILTER_RULE "kaffeine.*.debug=true"
+
+#define CATEGORIES "cam, dev, dvb, dvbsi, epg, config, mediawidget, playlist, sql"
+
 class StackedLayout : public QStackedLayout
 {
 public:
@@ -164,7 +182,15 @@ void MainWindow::run()
 	// Allow the user to enable or disable debugging
 	// We handle this before the other parameters, as it may affect some
 	// early debug messages
-        QLoggingCategory::defaultCategory()->setEnabled(QtDebugMsg, parser->isSet("debug"));
+	//
+	// --debug enables all debugging categories. It is possible to enable
+	// each category individually by calling Kaffeine with:
+	//	QT_LOGGING_RULES="epg.debug=true" kaffeine
+
+	if (parser->isSet("debug")) {
+		QLoggingCategory::defaultCategory()->setEnabled(QtDebugMsg, true);
+		QLoggingCategory::setFilterRules(QStringLiteral(FILTER_RULE));
+	}
 
 	readSettings();
 
@@ -469,7 +495,7 @@ MainWindow::MainWindow(KAboutData *aboutData, QCommandLineParser *parser)
 	this->aboutData = aboutData;
 	this->parser = parser;
 
-	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("d") << QLatin1String("debug"), i18n("Enable debug messages")));
+	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("d") << QLatin1String("debug"), i18n("Enable all debug messages. Please notice that Kaffeine also allows enabling debug messages per category, by using the environment var:\nQT_LOGGING_RULES=kaffeine.category.debug=true\nwhere 'category' can be:\n" CATEGORIES)));
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("tempfile"), i18n("The files/URLs opened by the application will be deleted after use")));
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("f") << QLatin1String("fullscreen"), i18n("Start in full screen mode")));
 	parser->addOption(QCommandLineOption(QStringList() << QLatin1String("audiocd"), i18n("Play Audio CD")));
